package info.bukova.isspst.data;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import org.hibernate.annotations.LazyCollection;
import org.hibernate.annotations.LazyCollectionOption;

@Entity
@Table(name = "WORKGROUP")
public class Workgroup extends Member implements OwnedDataModel { 
	
	@Column(name = "CODE")
	private String code;
	@Column(name = "NAME")
	private String name;
	@ManyToMany(cascade = {CascadeType.ALL})
	@LazyCollection(LazyCollectionOption.FALSE)
	@JoinTable(name="WORKGROUP_MEMBER", joinColumns={@JoinColumn(name="WORKGROUP_ID")}, inverseJoinColumns={@JoinColumn(name="JOBMAPPING_ID")})
	private List<JobMapping> members;
	@Column(name = "CENTRE")
	private boolean centre;
	//BaseData
	@ManyToOne(fetch=FetchType.EAGER)
	@JoinColumn(name="OWNED_BY_ID")
	private User ownedBy;
	@ManyToOne(fetch=FetchType.EAGER)
	@JoinColumn(name="MODIFIED_BY_ID")
	private User modifiedBy;


	public Workgroup() {
		members = new ArrayList<JobMapping>();
		centre = false;
	}
	
	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public boolean isCentre() {
		return centre;
	}

	public void setCentre(boolean centre) {
		this.centre = centre;
	}

	@Override
	public void setOwnedBy(User user) {
		this.ownedBy = user;
	}

	@Override
	public User getOwnedBy() {
		return ownedBy;
	}

	@Override
	public void setModifiedBy(User user) {
		this.modifiedBy = user;
	}

	@Override
	public User getModifiedBy() {
		return modifiedBy;
	}

	@Override
	public String getFullName() {
		return name;
	}

	@Override
	public boolean isHasJob() {
		return false;
	}

	public List<JobMapping> getMembers() {
		return members;
	}

	public void setMembers(List<JobMapping> members) {
		this.members = members;
	}
	
	public void removeMember(JobMapping mapping) {
		members.remove(mapping);
	}
	
	public void removeMember(Member member, Role role) {
		JobMapping mapping = new JobMapping(member, role);
		members.remove(mapping);
	}
	
	public boolean equals(Object o) {
		if (o instanceof Workgroup && ((Workgroup)o).getId() == this.getId()) {
			return true;
		}
		return false;
	}
	
}
