package info.bukova.isspst.services.workgroups;

import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import info.bukova.isspst.Constants;
import info.bukova.isspst.data.JobMapping;
import info.bukova.isspst.data.Member;
import info.bukova.isspst.data.Role;
import info.bukova.isspst.data.Workgroup;
import info.bukova.isspst.services.AbstractOwnedService;

public class WorkgroupServiceImpl extends AbstractOwnedService<Workgroup> implements WorkgroupService {

	@Override
	public void addMember(Workgroup workgroup, Member member, Role role) {
		if (!member.isHasJob() && !role.getAuthority().equals(Constants.ROLE_USER)) {
			throw new WorkgroupException(WorkgroupException.NO_WORGROUP);
		}
		if (workgroup.isCentre() && !role.isCentre()) {
			throw new WorkgroupException(WorkgroupException.MSUT_HAS_CENTER);
		}
		if (!workgroup.isCentre() && !role.isWorkgroup()) {
			throw new WorkgroupException(WorkgroupException.MUST_HAS_WORKGROUP);
		}
		
		JobMapping mapping = new JobMapping(member, role);
		if (!workgroup.getMembers().contains(mapping)) {
			workgroup.getMembers().add(mapping);
		}
	}

	@Override
	@Transactional
	public List<Workgroup> getWorkgroups() {
		return this.execQuery("from Workgroup where centre = false");
	}

	@Override
	@Transactional
	public List<Workgroup> getCentres() {
		return this.execQuery("from Workgroup where centre = true");
	}

	@Override
	public boolean isMember(Workgroup workgroup, Member member) {
		for (JobMapping jm : workgroup.getMembers()) {
			if (jm.getMember().equals(member)) {
				return true;
			}
		}
		
		return false;
	}

}
